# coding: utf-8

# flake8: noqa
"""
    qoery's API

    Every number on the internet, queryable. Instant access to millions of trusted statistics through a single natural language query or API call.  # Installation  ### Python SDK  Install from PyPI:  ```bash pip install qoery ```  PyPI: [qoery](https://pypi.org/project/qoery/)  ### JavaScript SDK  Install from npm:  ```bash npm install qoery ```  npm: [qoery](https://www.npmjs.com/package/qoery) 

    The version of the OpenAPI document: 0.2.0
    Contact: samuel.tinnerholm@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from qoery.models.error_response import ErrorResponse
from qoery.models.nl_query_request import NLQueryRequest
from qoery.models.query_nl_post200_response import QueryNlPost200Response
from qoery.models.query_nl_post200_response_meta import QueryNlPost200ResponseMeta
from qoery.models.query_nl_post200_response_meta_page import QueryNlPost200ResponseMetaPage
from qoery.models.query_nl_post200_response_series_inner import QueryNlPost200ResponseSeriesInner
from qoery.models.query_nl_post200_response_series_inner_entity import QueryNlPost200ResponseSeriesInnerEntity
from qoery.models.query_nl_post200_response_series_inner_metric import QueryNlPost200ResponseSeriesInnerMetric
from qoery.models.query_nl_post200_response_series_inner_observations_inner import QueryNlPost200ResponseSeriesInnerObservationsInner
from qoery.models.query_nl_post200_response_series_inner_observations_inner_value import QueryNlPost200ResponseSeriesInnerObservationsInnerValue
from qoery.models.query_nl_post200_response_series_inner_unit import QueryNlPost200ResponseSeriesInnerUnit
from qoery.models.query_nl_post400_response import QueryNlPost400Response
from qoery.models.query_nl_post_request import QueryNlPostRequest
from qoery.models.query_response import QueryResponse
from qoery.models.query_sql_post_request import QuerySqlPostRequest
from qoery.models.sql_query_request import SQLQueryRequest
from qoery.models.scrape_post200_response import ScrapePost200Response
from qoery.models.scrape_post200_response_artifacts import ScrapePost200ResponseArtifacts
from qoery.models.scrape_post200_response_metadata import ScrapePost200ResponseMetadata
from qoery.models.scrape_post_request import ScrapePostRequest
from qoery.models.scrape_response import ScrapeResponse
from qoery.models.url_request import URLRequest
from qoery.models.usage_get200_response import UsageGet200Response
from qoery.models.usage_get200_response_endpoints import UsageGet200ResponseEndpoints
from qoery.models.usage_get200_response_endpoints_nl import UsageGet200ResponseEndpointsNl
from qoery.models.usage_stats import UsageStats



# coding: utf-8

"""
    qoery's API

    Every number on the internet, queryable. Instant access to millions of trusted statistics through a single natural language query or API call.  # Installation  ### Python SDK  Install from PyPI:  ```bash pip install qoery ```  PyPI: [qoery](https://pypi.org/project/qoery/)  ### JavaScript SDK  Install from npm:  ```bash npm install qoery ```  npm: [qoery](https://www.npmjs.com/package/qoery) 

    The version of the OpenAPI document: 0.2.0
    Contact: samuel.tinnerholm@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool
from typing import Optional
from typing_extensions import Annotated
from qoery.models.scrape_post200_response import ScrapePost200Response
from qoery.models.scrape_post_request import ScrapePostRequest

from qoery.api_client import ApiClient, RequestSerialized
from qoery.api_response import ApiResponse
from qoery.rest import RESTResponseType


class WebScrapingApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def scrape_post(
        self,
        html: Annotated[Optional[StrictBool], Field(description="Include page HTML inline in response")] = None,
        markdown: Annotated[Optional[StrictBool], Field(description="Include page markdown inline in response")] = None,
        scrape_post_request: Annotated[Optional[ScrapePostRequest], Field(description="Provide JSON body or use query parameter 'url'. Body takes precedence.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ScrapePost200Response:
        """Structured Web Scrape

        Download a web page, and structured data as time series. Use query params `html=true` and/or `markdown=true` to include raw artifacts inline; otherwise artifact URLs are provided in `artifacts`.

        :param html: Include page HTML inline in response
        :type html: bool
        :param markdown: Include page markdown inline in response
        :type markdown: bool
        :param scrape_post_request: Provide JSON body or use query parameter 'url'. Body takes precedence.
        :type scrape_post_request: ScrapePostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._scrape_post_serialize(
            html=html,
            markdown=markdown,
            scrape_post_request=scrape_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ScrapePost200Response",
            '400': "QueryNlPost400Response",
            '401': "QueryNlPost400Response",
            '429': "QueryNlPost400Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def scrape_post_with_http_info(
        self,
        html: Annotated[Optional[StrictBool], Field(description="Include page HTML inline in response")] = None,
        markdown: Annotated[Optional[StrictBool], Field(description="Include page markdown inline in response")] = None,
        scrape_post_request: Annotated[Optional[ScrapePostRequest], Field(description="Provide JSON body or use query parameter 'url'. Body takes precedence.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ScrapePost200Response]:
        """Structured Web Scrape

        Download a web page, and structured data as time series. Use query params `html=true` and/or `markdown=true` to include raw artifacts inline; otherwise artifact URLs are provided in `artifacts`.

        :param html: Include page HTML inline in response
        :type html: bool
        :param markdown: Include page markdown inline in response
        :type markdown: bool
        :param scrape_post_request: Provide JSON body or use query parameter 'url'. Body takes precedence.
        :type scrape_post_request: ScrapePostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._scrape_post_serialize(
            html=html,
            markdown=markdown,
            scrape_post_request=scrape_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ScrapePost200Response",
            '400': "QueryNlPost400Response",
            '401': "QueryNlPost400Response",
            '429': "QueryNlPost400Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def scrape_post_without_preload_content(
        self,
        html: Annotated[Optional[StrictBool], Field(description="Include page HTML inline in response")] = None,
        markdown: Annotated[Optional[StrictBool], Field(description="Include page markdown inline in response")] = None,
        scrape_post_request: Annotated[Optional[ScrapePostRequest], Field(description="Provide JSON body or use query parameter 'url'. Body takes precedence.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Structured Web Scrape

        Download a web page, and structured data as time series. Use query params `html=true` and/or `markdown=true` to include raw artifacts inline; otherwise artifact URLs are provided in `artifacts`.

        :param html: Include page HTML inline in response
        :type html: bool
        :param markdown: Include page markdown inline in response
        :type markdown: bool
        :param scrape_post_request: Provide JSON body or use query parameter 'url'. Body takes precedence.
        :type scrape_post_request: ScrapePostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._scrape_post_serialize(
            html=html,
            markdown=markdown,
            scrape_post_request=scrape_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ScrapePost200Response",
            '400': "QueryNlPost400Response",
            '401': "QueryNlPost400Response",
            '429': "QueryNlPost400Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _scrape_post_serialize(
        self,
        html,
        markdown,
        scrape_post_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if html is not None:
            
            _query_params.append(('html', html))
            
        if markdown is not None:
            
            _query_params.append(('markdown', markdown))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if scrape_post_request is not None:
            _body_params = scrape_post_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/scrape',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    qoery's API

    Every number on the internet, queryable. Instant access to millions of trusted statistics through a single natural language query or API call.  # Installation  ### Python SDK  Install from PyPI:  ```bash pip install qoery ```  PyPI: [qoery](https://pypi.org/project/qoery/)  ### JavaScript SDK  Install from npm:  ```bash npm install qoery ```  npm: [qoery](https://www.npmjs.com/package/qoery) 

    The version of the OpenAPI document: 0.1.0
    Contact: samuel.tinnerholm@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qoery.models.usage_get200_response import UsageGet200Response

class TestUsageGet200Response(unittest.TestCase):
    """UsageGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UsageGet200Response:
        """Test UsageGet200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UsageGet200Response`
        """
        model = UsageGet200Response()
        if include_optional:
            return UsageGet200Response(
                period_start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                period_end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                plan = '',
                endpoints = qoery.models._usage_get_200_response_endpoints._usage_get_200_response_endpoints(
                    nl = qoery.models._usage_get_200_response_endpoints_nl._usage_get_200_response_endpoints_nl(
                        calls_used = 56, 
                        calls_limit = '', 
                        tokens_in = 56, 
                        tokens_out = 56, 
                        errors = 56, 
                        remaining = 56, ), 
                    sql = qoery.models._usage_get_200_response_endpoints_nl._usage_get_200_response_endpoints_nl(
                        calls_used = 56, 
                        calls_limit = '', 
                        tokens_in = 56, 
                        tokens_out = 56, 
                        errors = 56, 
                        remaining = 56, ), 
                    scrape = , )
            )
        else:
            return UsageGet200Response(
                period_start = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                period_end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                plan = '',
                endpoints = qoery.models._usage_get_200_response_endpoints._usage_get_200_response_endpoints(
                    nl = qoery.models._usage_get_200_response_endpoints_nl._usage_get_200_response_endpoints_nl(
                        calls_used = 56, 
                        calls_limit = '', 
                        tokens_in = 56, 
                        tokens_out = 56, 
                        errors = 56, 
                        remaining = 56, ), 
                    sql = qoery.models._usage_get_200_response_endpoints_nl._usage_get_200_response_endpoints_nl(
                        calls_used = 56, 
                        calls_limit = '', 
                        tokens_in = 56, 
                        tokens_out = 56, 
                        errors = 56, 
                        remaining = 56, ), 
                    scrape = , ),
        )
        """

    def testUsageGet200Response(self):
        """Test UsageGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    qoery's API

    Every number on the internet, queryable. Instant access to millions of trusted statistics through a single natural language query or API call.  # Installation  ### Python SDK  Install from PyPI:  ```bash pip install qoery ```  PyPI: [qoery](https://pypi.org/project/qoery/)  ### JavaScript SDK  Install from npm:  ```bash npm install qoery ```  npm: [qoery](https://www.npmjs.com/package/qoery) 

    The version of the OpenAPI document: 0.1.0
    Contact: samuel.tinnerholm@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qoery.api.queries_api import QueriesApi


class TestQueriesApi(unittest.TestCase):
    """QueriesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = QueriesApi()

    def tearDown(self) -> None:
        pass

    def test_query_nl_post(self) -> None:
        """Test case for query_nl_post

        Natural Language Query
        """
        pass

    def test_query_sql_post(self) -> None:
        """Test case for query_sql_post

        SQL Query
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    qoery's API

    Every number on the internet, queryable. Instant access to millions of trusted statistics through a single natural language query or API call.  # Installation  ### Python SDK  Install from PyPI:  ```bash pip install qoery ```  PyPI: [qoery](https://pypi.org/project/qoery/)  ### JavaScript SDK  Install from npm:  ```bash npm install qoery ```  npm: [qoery](https://www.npmjs.com/package/qoery) 

    The version of the OpenAPI document: 0.1.0
    Contact: samuel.tinnerholm@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qoery.models.query_nl_post_request import QueryNlPostRequest

class TestQueryNlPostRequest(unittest.TestCase):
    """QueryNlPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> QueryNlPostRequest:
        """Test QueryNlPostRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `QueryNlPostRequest`
        """
        model = QueryNlPostRequest()
        if include_optional:
            return QueryNlPostRequest(
                query = ''
            )
        else:
            return QueryNlPostRequest(
                query = '',
        )
        """

    def testQueryNlPostRequest(self):
        """Test QueryNlPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    qoery's API

    Every number on the internet, queryable. Instant access to millions of trusted statistics through a single natural language query or API call.  # Installation  ### Python SDK  Install from PyPI:  ```bash pip install qoery ```  PyPI: [qoery](https://pypi.org/project/qoery/)  ### JavaScript SDK  Install from npm:  ```bash npm install qoery ```  npm: [qoery](https://www.npmjs.com/package/qoery) 

    The version of the OpenAPI document: 0.2.0
    Contact: samuel.tinnerholm@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from qoery.models.query_nl_post200_response_series_inner import QueryNlPost200ResponseSeriesInner
from qoery.models.scrape_post200_response_artifacts import ScrapePost200ResponseArtifacts
from qoery.models.scrape_post200_response_metadata import ScrapePost200ResponseMetadata
from typing import Optional, Set
from typing_extensions import Self

class ScrapeResponse(BaseModel):
    """
    Response from web scraping endpoint
    """ # noqa: E501
    series: List[QueryNlPost200ResponseSeriesInner] = Field(description="Array of series with observations (same structure as query endpoints)")
    artifacts: Optional[ScrapePost200ResponseArtifacts] = None
    cached: Optional[StrictBool] = Field(default=None, description="Whether this result was retrieved from cache")
    source_id: Optional[StrictStr] = Field(default=None, description="Database source ID (present when cached=true)")
    metadata: Optional[ScrapePost200ResponseMetadata] = None
    html: Optional[StrictStr] = Field(default=None, description="Original HTML of the page (only if html=true query param)")
    markdown: Optional[StrictStr] = Field(default=None, description="Markdown representation of the page (only if markdown=true query param)")
    __properties: ClassVar[List[str]] = ["series", "artifacts", "cached", "source_id", "metadata", "html", "markdown"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ScrapeResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in series (list)
        _items = []
        if self.series:
            for _item_series in self.series:
                if _item_series:
                    _items.append(_item_series.to_dict())
            _dict['series'] = _items
        # override the default output from pydantic by calling `to_dict()` of artifacts
        if self.artifacts:
            _dict['artifacts'] = self.artifacts.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict['metadata'] = self.metadata.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ScrapeResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "series": [QueryNlPost200ResponseSeriesInner.from_dict(_item) for _item in obj["series"]] if obj.get("series") is not None else None,
            "artifacts": ScrapePost200ResponseArtifacts.from_dict(obj["artifacts"]) if obj.get("artifacts") is not None else None,
            "cached": obj.get("cached"),
            "source_id": obj.get("source_id"),
            "metadata": ScrapePost200ResponseMetadata.from_dict(obj["metadata"]) if obj.get("metadata") is not None else None,
            "html": obj.get("html"),
            "markdown": obj.get("markdown")
        })
        return _obj





# coding: utf-8

"""
    qoery's API

    Every number on the internet, queryable. Instant access to millions of trusted statistics through a single natural language query or API call.  # Installation  ### Python SDK  Install from PyPI:  ```bash pip install qoery ```  PyPI: [qoery](https://pypi.org/project/qoery/)  ### JavaScript SDK  Install from npm:  ```bash npm install qoery ```  npm: [qoery](https://www.npmjs.com/package/qoery) 

    The version of the OpenAPI document: 0.2.0
    Contact: samuel.tinnerholm@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "qoery"
VERSION = "0.2.0"
PYTHON_REQUIRES = ">= 3.9"
REQUIRES = [
    "urllib3 >= 2.1.0, < 3.0.0",
    "python-dateutil >= 2.8.2",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="qoery&#39;s API",
    author="qoery Support",
    author_email="samuel.tinnerholm@gmail.com",
    url="https://github.com/qoery/python-sdk",
    keywords=["OpenAPI", "OpenAPI-Generator", "qoery's API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="MIT",
    long_description_content_type='text/markdown',
    long_description="""\
    Every number on the internet, queryable. Instant access to millions of trusted statistics through a single natural language query or API call.  # Installation  ### Python SDK  Install from PyPI:  &#x60;&#x60;&#x60;bash pip install qoery &#x60;&#x60;&#x60;  PyPI: [qoery](https://pypi.org/project/qoery/)  ### JavaScript SDK  Install from npm:  &#x60;&#x60;&#x60;bash npm install qoery &#x60;&#x60;&#x60;  npm: [qoery](https://www.npmjs.com/package/qoery) 
    """,  # noqa: E501
    package_data={"qoery": ["py.typed"]},
)


# coding: utf-8

"""
    qoery's API

    Every number on the internet, queryable. Instant access to millions of trusted statistics through a single natural language query or API call.  # Installation  ### Python SDK  Install from PyPI:  ```bash pip install qoery ```  PyPI: [qoery](https://pypi.org/project/qoery/)  ### JavaScript SDK  Install from npm:  ```bash npm install qoery ```  npm: [qoery](https://www.npmjs.com/package/qoery) 

    The version of the OpenAPI document: 0.1.0
    Contact: samuel.tinnerholm@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qoery.models.scrape_response import ScrapeResponse

class TestScrapeResponse(unittest.TestCase):
    """ScrapeResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ScrapeResponse:
        """Test ScrapeResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ScrapeResponse`
        """
        model = ScrapeResponse()
        if include_optional:
            return ScrapeResponse(
                series = [
                    qoery.models._query_nl_post_200_response_series_inner._query_nl_post_200_response_series_inner(
                        id = '', 
                        name = '', 
                        entity = qoery.models._query_nl_post_200_response_series_inner_entity._query_nl_post_200_response_series_inner_entity(
                            id = '', 
                            name = '', ), 
                        metric = qoery.models._query_nl_post_200_response_series_inner_metric._query_nl_post_200_response_series_inner_metric(
                            id = '', 
                            name = '', ), 
                        unit = qoery.models._query_nl_post_200_response_series_inner_unit._query_nl_post_200_response_series_inner_unit(
                            id = '', 
                            name = '', 
                            symbol = '', ), 
                        frequency = '', 
                        description = '', 
                        labels = { }, 
                        observations = [
                            qoery.models._query_nl_post_200_response_series_inner_observations_inner._query_nl_post_200_response_series_inner_observations_inner(
                                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                value = null, )
                            ], )
                    ],
                artifacts = qoery.models._scrape_post_200_response_artifacts._scrape_post_200_response_artifacts(
                    html_url = '', 
                    markdown_url = '', 
                    tables_base_url = '', ),
                cached = True,
                source_id = '',
                metadata = { },
                html = '',
                markdown = ''
            )
        else:
            return ScrapeResponse(
                series = [
                    qoery.models._query_nl_post_200_response_series_inner._query_nl_post_200_response_series_inner(
                        id = '', 
                        name = '', 
                        entity = qoery.models._query_nl_post_200_response_series_inner_entity._query_nl_post_200_response_series_inner_entity(
                            id = '', 
                            name = '', ), 
                        metric = qoery.models._query_nl_post_200_response_series_inner_metric._query_nl_post_200_response_series_inner_metric(
                            id = '', 
                            name = '', ), 
                        unit = qoery.models._query_nl_post_200_response_series_inner_unit._query_nl_post_200_response_series_inner_unit(
                            id = '', 
                            name = '', 
                            symbol = '', ), 
                        frequency = '', 
                        description = '', 
                        labels = { }, 
                        observations = [
                            qoery.models._query_nl_post_200_response_series_inner_observations_inner._query_nl_post_200_response_series_inner_observations_inner(
                                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                value = null, )
                            ], )
                    ],
        )
        """

    def testScrapeResponse(self):
        """Test ScrapeResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    qoery's API

    Every number on the internet, queryable. Instant access to millions of trusted statistics through a single natural language query or API call.  # Installation  ### Python SDK  Install from PyPI:  ```bash pip install qoery ```  PyPI: [qoery](https://pypi.org/project/qoery/)  ### JavaScript SDK  Install from npm:  ```bash npm install qoery ```  npm: [qoery](https://www.npmjs.com/package/qoery) 

    The version of the OpenAPI document: 0.2.0
    Contact: samuel.tinnerholm@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.2.0"

# Define package exports
__all__ = [
    "QueriesApi",
    "UsageApi",
    "WebScrapingApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ErrorResponse",
    "NLQueryRequest",
    "QueryNlPost200Response",
    "QueryNlPost200ResponseMeta",
    "QueryNlPost200ResponseMetaPage",
    "QueryNlPost200ResponseSeriesInner",
    "QueryNlPost200ResponseSeriesInnerEntity",
    "QueryNlPost200ResponseSeriesInnerMetric",
    "QueryNlPost200ResponseSeriesInnerObservationsInner",
    "QueryNlPost200ResponseSeriesInnerObservationsInnerValue",
    "QueryNlPost200ResponseSeriesInnerUnit",
    "QueryNlPost400Response",
    "QueryNlPostRequest",
    "QueryResponse",
    "QuerySqlPostRequest",
    "SQLQueryRequest",
    "ScrapePost200Response",
    "ScrapePost200ResponseArtifacts",
    "ScrapePost200ResponseMetadata",
    "ScrapePostRequest",
    "ScrapeResponse",
    "URLRequest",
    "UsageGet200Response",
    "UsageGet200ResponseEndpoints",
    "UsageGet200ResponseEndpointsNl",
    "UsageStats",
]

# import apis into sdk package
from qoery.api.queries_api import QueriesApi as QueriesApi
from qoery.api.usage_api import UsageApi as UsageApi
from qoery.api.web_scraping_api import WebScrapingApi as WebScrapingApi

# import ApiClient
from qoery.api_response import ApiResponse as ApiResponse
from qoery.api_client import ApiClient as ApiClient
from qoery.configuration import Configuration as Configuration
from qoery.exceptions import OpenApiException as OpenApiException
from qoery.exceptions import ApiTypeError as ApiTypeError
from qoery.exceptions import ApiValueError as ApiValueError
from qoery.exceptions import ApiKeyError as ApiKeyError
from qoery.exceptions import ApiAttributeError as ApiAttributeError
from qoery.exceptions import ApiException as ApiException

# import models into sdk package
from qoery.models.error_response import ErrorResponse as ErrorResponse
from qoery.models.nl_query_request import NLQueryRequest as NLQueryRequest
from qoery.models.query_nl_post200_response import QueryNlPost200Response as QueryNlPost200Response
from qoery.models.query_nl_post200_response_meta import QueryNlPost200ResponseMeta as QueryNlPost200ResponseMeta
from qoery.models.query_nl_post200_response_meta_page import QueryNlPost200ResponseMetaPage as QueryNlPost200ResponseMetaPage
from qoery.models.query_nl_post200_response_series_inner import QueryNlPost200ResponseSeriesInner as QueryNlPost200ResponseSeriesInner
from qoery.models.query_nl_post200_response_series_inner_entity import QueryNlPost200ResponseSeriesInnerEntity as QueryNlPost200ResponseSeriesInnerEntity
from qoery.models.query_nl_post200_response_series_inner_metric import QueryNlPost200ResponseSeriesInnerMetric as QueryNlPost200ResponseSeriesInnerMetric
from qoery.models.query_nl_post200_response_series_inner_observations_inner import QueryNlPost200ResponseSeriesInnerObservationsInner as QueryNlPost200ResponseSeriesInnerObservationsInner
from qoery.models.query_nl_post200_response_series_inner_observations_inner_value import QueryNlPost200ResponseSeriesInnerObservationsInnerValue as QueryNlPost200ResponseSeriesInnerObservationsInnerValue
from qoery.models.query_nl_post200_response_series_inner_unit import QueryNlPost200ResponseSeriesInnerUnit as QueryNlPost200ResponseSeriesInnerUnit
from qoery.models.query_nl_post400_response import QueryNlPost400Response as QueryNlPost400Response
from qoery.models.query_nl_post_request import QueryNlPostRequest as QueryNlPostRequest
from qoery.models.query_response import QueryResponse as QueryResponse
from qoery.models.query_sql_post_request import QuerySqlPostRequest as QuerySqlPostRequest
from qoery.models.sql_query_request import SQLQueryRequest as SQLQueryRequest
from qoery.models.scrape_post200_response import ScrapePost200Response as ScrapePost200Response
from qoery.models.scrape_post200_response_artifacts import ScrapePost200ResponseArtifacts as ScrapePost200ResponseArtifacts
from qoery.models.scrape_post200_response_metadata import ScrapePost200ResponseMetadata as ScrapePost200ResponseMetadata
from qoery.models.scrape_post_request import ScrapePostRequest as ScrapePostRequest
from qoery.models.scrape_response import ScrapeResponse as ScrapeResponse
from qoery.models.url_request import URLRequest as URLRequest
from qoery.models.usage_get200_response import UsageGet200Response as UsageGet200Response
from qoery.models.usage_get200_response_endpoints import UsageGet200ResponseEndpoints as UsageGet200ResponseEndpoints
from qoery.models.usage_get200_response_endpoints_nl import UsageGet200ResponseEndpointsNl as UsageGet200ResponseEndpointsNl
from qoery.models.usage_stats import UsageStats as UsageStats
